@@ -25,6 +25,7 @@
 #include <errno.h>
 #include <config.h>
 #include <math.h>
+#include <time.h>
 #include <gnome.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
@@ -40,8 +41,8 @@
 
 /* Default size for windows */
 
-#define DEFAULT_WINDOW_WIDTH 200
-#define DEFAULT_WINDOW_HEIGHT 200
+#define DEFAULT_WINDOW_WIDTH 310
+#define DEFAULT_WINDOW_HEIGHT 280
 
 #define EOG_VIEWER_CONTROL_IID "OAFIID:GNOME_EOG_Control"
 #define EOG_WINDOW_DND_POPUP_PATH  "/popups/dragndrop"
@@ -51,8 +52,14 @@ struct _EogWindowPrivate {
 	/* Our GConf client */
 	GConfClient *client;
 
+	/* URI we are displaying */
+	char *uri;
+
 	/* control frame */
-	BonoboControlFrame *ctrl_frame;
+	BonoboControlFrame  *ctrl_frame;
+
+	/* UI component - arn't these comments banal */
+	BonoboUIComponent   *ui_comp;
 
 	/* vbox */
 	GtkWidget           *box;
@@ -95,6 +102,38 @@ enum {
 
 
 
+/* Computes a unique ID string for use as the window role */
+static char *
+gen_role (void)
+{
+        char *ret;
+	static char *hostname;
+	time_t t;
+	static int serial;
+
+	t = time (NULL);
+
+	if (!hostname) {
+		static char buffer [512];
+
+		if ((gethostname (buffer, sizeof (buffer) - 1) == 0) &&
+		    (buffer [0] != 0))
+			hostname = buffer;
+		else
+			hostname = "localhost";
+	}
+
+	ret = g_strdup_printf ("eog-window-%d-%d-%d-%ld-%d@%s",
+			       getpid (),
+			       getgid (),
+			       getppid (),
+			       (long) t,
+			       serial++,
+			       hostname);
+
+	return ret;
+}
+
 /* Brings attention to a window by raising it and giving it focus */
 static void
 raise_and_focus (GtkWidget *widget)
@@ -128,9 +167,9 @@ verb_Preferences_cb (BonoboUIComponent *uic, gpointer user_data, const char *cna
 
 	if (priv->pref_dlg == NULL) {
 		priv->pref_dlg = eog_preferences_new (window);
-		gtk_signal_connect (GTK_OBJECT (priv->pref_dlg), "destroy", 
-				    GTK_SIGNAL_FUNC (preference_dlg_closed_cb),
-				    window);
+		g_signal_connect (priv->pref_dlg, "destroy", 
+				  G_CALLBACK (preference_dlg_closed_cb),
+				  window);
 	}
 
 	gtk_window_present (GTK_WINDOW (priv->pref_dlg));
@@ -206,15 +245,47 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname
 			NULL, /* char **documentors */
 			translator_credits,
 			NULL);
-		gtk_signal_connect (GTK_OBJECT (about), "destroy",
-				    GTK_SIGNAL_FUNC (gtk_widget_destroyed),
-				    &about);
+		g_signal_connect (about, "destroy",
+				  G_CALLBACK (gtk_widget_destroyed),
+				  &about);
 	}
 
 	gtk_widget_show_now (about);
 	raise_and_focus (about);
 }
 
+static void
+verb_HelpContent_cb (BonoboUIComponent *uic, gpointer data, const char *cname)
+{
+	GError *error;
+	EogWindow *window;
+
+	window = EOG_WINDOW (data);
+
+	error = NULL;
+	gnome_help_display ("eog", NULL, &error);
+
+	if (error) {
+		GtkWidget *dialog;
+
+		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+						 0,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 _("Could not display help for Eye of Gnome.\n"
+						   "%s"),
+						 error->message);
+
+		g_signal_connect_swapped (dialog, "response",
+					  G_CALLBACK (gtk_widget_destroy),
+					  dialog);
+		gtk_widget_show (dialog);
+
+		g_error_free (error);
+	}
+}
+
+
 static void
 verb_DnDNewWindow_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
@@ -245,7 +316,7 @@ activate_uri_cb (BonoboControlFrame *control_frame, const char *uri, gboolean re
 
 	window = EOG_WINDOW (eog_window_new ());
 	
-	if (g_strncasecmp ("file:", uri, 5) == 0) 		
+	if (g_ascii_strncasecmp ("file:", uri, 5) == 0) 		
 		path = g_strdup ((uri+5));
 	else
 		path = g_strdup (uri);
@@ -299,6 +370,11 @@ eog_window_destroy (GtkObject *object)
 	window = EOG_WINDOW (object);
 	priv = window->priv;
 
+	if (priv->uri) {
+		g_free (priv->uri);
+		priv->uri = NULL;
+	}
+
 	if (priv->ctrl_frame != NULL) {
 		bonobo_object_unref (BONOBO_OBJECT (priv->ctrl_frame));
 		priv->ctrl_frame = NULL;
@@ -375,10 +451,16 @@ static void
 eog_window_init (EogWindow *window)
 {
 	EogWindowPrivate *priv;
+	char *role;
 
 	priv = g_new0 (EogWindowPrivate, 1);
 	window->priv = priv;
 
+	role = gen_role ();
+	gtk_window_set_role (GTK_WINDOW (window), role);
+
+	priv->uri = NULL;
+
 	priv->pref_dlg = NULL;
 	
 	priv->client = gconf_client_get_default ();
@@ -397,7 +479,7 @@ eog_window_init (EogWindow *window)
 
 	window_list = g_list_prepend (window_list, window);
 
-	gtk_window_set_policy (GTK_WINDOW (window), TRUE, TRUE, FALSE);
+	g_object_set (G_OBJECT (window), "allow_shrink", TRUE, NULL);
 }
 
 /* delete_event handler for windows */
@@ -458,8 +540,6 @@ eog_window_drag_data_received (GtkWidget *widget,
 {
 	EogWindow *window;
 	EogWindowPrivate *priv;
-	GList *filenames = NULL;
-	GList *l;
 	gboolean need_new_window = TRUE;
 
 	window = EOG_WINDOW (widget);
@@ -541,12 +621,8 @@ GtkWidget *
 eog_window_new (void)
 {
 	EogWindow *window;
-	BonoboUIContainer *uic;
 
-	window = EOG_WINDOW (g_object_new (EOG_TYPE_WINDOW, NULL));
-
-	uic = bonobo_ui_container_new ();
-	bonobo_window_construct (BONOBO_WINDOW (window), uic, "eog", _("Eye of Gnome"));
+	window = EOG_WINDOW (g_object_new (EOG_TYPE_WINDOW, "win_name", "eog", "title", _("Eye of Gnome"), NULL));
 
 	eog_window_construct (window);
 
@@ -576,6 +652,7 @@ static BonoboUIVerb eog_app_verbs[] = {
 	BONOBO_UI_VERB ("FileExit",      verb_FileExit_cb),
 	BONOBO_UI_VERB ("Preferences",   verb_Preferences_cb),
 	BONOBO_UI_VERB ("HelpAbout",     verb_HelpAbout_cb),
+	BONOBO_UI_VERB ("Help",          verb_HelpContent_cb),
 	BONOBO_UI_VERB ("DnDNewWindow",  verb_DnDNewWindow_cb),
 	BONOBO_UI_VERB ("DnDSameWindow", verb_DnDSameWindow_cb),
 	BONOBO_UI_VERB ("DnDCancel",     verb_DnDCancel_cb),
@@ -594,8 +671,6 @@ eog_window_construct (EogWindow *window)
 {
 	EogWindowPrivate *priv;
 	BonoboUIContainer *ui_container;
-	BonoboUIComponent *ui_comp;
-	GdkGeometry geometry;
 
 	g_return_if_fail (window != NULL);
 	g_return_if_fail (EOG_IS_WINDOW (window));
@@ -613,12 +688,12 @@ eog_window_construct (EogWindow *window)
 	bonobo_window_set_contents (BONOBO_WINDOW (window), priv->box);
 
 	/* add menu and toolbar */
-	ui_comp = bonobo_ui_component_new ("eog");
-	bonobo_ui_component_set_container (ui_comp, 
+	priv->ui_comp = bonobo_ui_component_new ("eog");
+	bonobo_ui_component_set_container (priv->ui_comp, 
 					   BONOBO_OBJREF (ui_container), NULL);
 
-	bonobo_ui_util_set_ui (ui_comp, NULL, "eog-shell-ui.xml", "EOG", NULL);
-	bonobo_ui_component_add_verb_list_with_data (ui_comp, eog_app_verbs, window);
+	bonobo_ui_util_set_ui (priv->ui_comp, NULL, "eog-shell-ui.xml", "EOG", NULL);
+	bonobo_ui_component_add_verb_list_with_data (priv->ui_comp, eog_app_verbs, window);
 
 	/* add statusbar */
 	priv->statusbar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_NEVER);
@@ -729,10 +804,10 @@ property_changed_cb (BonoboListener    *listener,
 
 	window = EOG_WINDOW (user_data);
 
-	if (!g_strcasecmp (event_name, "window/title"))
+	if (!g_ascii_strcasecmp (event_name, "window/title"))
 		gtk_window_set_title (GTK_WINDOW (window),
 				      BONOBO_ARG_GET_STRING (any));
-	else if (!g_strcasecmp (event_name, "window/status"))
+	else if (!g_ascii_strcasecmp (event_name, "window/status"))
 		gnome_appbar_set_status (GNOME_APPBAR (window->priv->statusbar),
 					 BONOBO_ARG_GET_STRING (any));		
 }
@@ -1000,28 +1075,19 @@ add_control_to_ui (EogWindow *window, Bonobo_Control control)
 	/* update sensitivity of the properties menu item */
 	prop_control = Bonobo_Unknown_queryInterface (control, 
 						      "IDL:Bonobo/PropertyControl:1.0", &ev);
-	if (prop_control == CORBA_OBJECT_NIL) {
-		bonobo_ui_engine_xml_set_prop (bonobo_window_get_ui_engine (BONOBO_WINDOW (window)),
-					       "/commands/Preferences",
-					       "sensitive", "0",
-					       "eog");
-	}
-	else {
-		bonobo_ui_engine_xml_set_prop (bonobo_window_get_ui_engine (BONOBO_WINDOW (window)),
-					       "/commands/Preferences",
-					       "sensitive", "1",
-					       "eog");
-		bonobo_object_release_unref (prop_control, &ev);
-	}
+	bonobo_ui_component_set_prop (priv->ui_comp,
+				      "/commands/Preferences",
+				      "sensitive",
+				      prop_control == CORBA_OBJECT_NIL ? "0" : "1",
+				      &ev);
+	
+	bonobo_object_release_unref (prop_control, &ev);
 
 	/* enable view menu */
 	/* FIXME: We should check if the component adds anything to 
 	 *        the menu, so that we don't view an empty menu.
 	 */
-	bonobo_ui_engine_xml_set_prop (bonobo_window_get_ui_engine (BONOBO_WINDOW (window)),
-				       "/menu/View",
-				       "hidden", "0",
-				       "eog");
+	bonobo_ui_component_set_prop (priv->ui_comp, "/menu/View", "hidden", "0", &ev);
 
 	CORBA_exception_free (&ev);
 
@@ -1097,9 +1163,10 @@ eog_window_open (EogWindow *window, const char *text_uri)
 					      _("Unable to open %s."),
 					      uri_str);
 
-		gtk_signal_connect_object (GTK_OBJECT (dlg), "response",
-					   GTK_SIGNAL_FUNC (gtk_widget_destroy),
-					   GTK_OBJECT (dlg));
+		g_signal_connect (dlg, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
 		gtk_widget_show (dlg);
 
 		g_free (uri_str);
@@ -1109,6 +1176,11 @@ eog_window_open (EogWindow *window, const char *text_uri)
 	gnome_vfs_file_info_unref (info);
 	gnome_vfs_uri_unref (uri);
 
+	if (priv->uri)
+		g_free (priv->uri);
+
+	priv->uri = g_strdup (text_uri);
+
 	return TRUE;
 }
 
@@ -1150,3 +1222,37 @@ eog_window_get_property_control (EogWindow *window, CORBA_Environment *ev)
 						      "IDL:Bonobo/PropertyControl:1.0", ev);
 	return prop_control;
 }
+
+/**
+ * eog_get_window_list:
+ *
+ * Gets a list of all #EogWindow objects.  You should not modify this list at
+ * all; it should be considered read-only.
+ * 
+ * Return value: A list with all the active #EogWindow objects.
+ **/
+GList *
+eog_get_window_list (void)
+{
+	return window_list;
+}
+
+/**
+ * eog_window_get_uri:
+ * @eog_window: A shell window.
+ * 
+ * Queries the URI that is being displayed by the specified window.  If the
+ * window is not displaying a single image or directory, this will return NULL.
+ * 
+ * Return value: The URI that is being displayed.
+ **/
+const char *
+eog_window_get_uri (EogWindow *eog_window)
+{
+	EogWindowPrivate *priv;
+
+	g_return_val_if_fail (EOG_IS_WINDOW (eog_window), NULL);
+
+	priv = eog_window->priv;
+	return priv->uri;
+}
